.. _user_guide:

User Guide
==========

.. rubric:: Beginner

.. toctree::
    :maxdepth: 1

    installation
    irreps
    convolution
    normalization

.. rubric:: Advanced

.. toctree::
    :maxdepth: 1

    periodic_boundary_conditions
    transformer
    equivar_testing
    jit
    change_of_basis
